//
//  ContentView.swift
//  Learn
//
//  Created by Mohammad Azam on 1/8/25.
//

import SwiftUI

protocol CreditScoreServiceProtocol {
    func getCreditScore(ssn: String) async -> Int?
}

struct MockCreditScoreService: CreditScoreServiceProtocol {
    
    var onGetCreditScore: ((String) -> Int?)?
    
    func getCreditScore(ssn: String) async -> Int? {
        return onGetCreditScore?(ssn)
    }
}

struct CreditScoreService: CreditScoreServiceProtocol {
    func getCreditScore(ssn: String) async -> Int? {
        return 700
    }
}

// We own it
struct APRService {
    
    let creditScoreService: CreditScoreServiceProtocol
    
    func getAPR(ssn: String) async -> Double {
        // call the creditScoreService to find the credit score of a person
        let creditScore = await creditScoreService.getCreditScore(ssn: ssn) ?? 0
        
        switch creditScore {
            case 750...:
                return 3.5  // Excellent credit score
            case 700..<750:
                return 5.0  // Good credit score
            case 650..<700:
                return 7.5  // Average credit score
            case 600..<650:
                return 10.0 // Below average credit score
            case ..<600:
                return 15.0 // Poor credit score
            default:
                return 10.9 // Default APR
        }
    }
    
}

struct ContentView: View {
    var body: some View {
        Text("Hello World")
    }
}

#Preview {
    ContentView()
}
